<?xml version="1.0"?>

<st-source>
<!-- Changes in change set probeMonitorTelusFix -->
<time-stamp>From VisualWorks®, 7.3.1 of April 20, 2005 on January 6, 2009 at 9:43:12 am</time-stamp>


<methods>
<class-id>PROVISO.ProbeDatabaseInterface</class-id> <category>accessing</category>

<body package="PV-SNMP Collector" selector="loadPropertyIdFor:">loadPropertyIdFor: propertyName
	"The actual property names stored in the DB are:
		49000034          DV_SAAProbeRebootCheckInterval
		49000035          DV_SAAProbeResyncInterval
		49000036          DV_SAAProbeMonitoringEnabled"

	propertyName = 'probeRebootCheckInterval' ifTrue: [^49000034].
	propertyName = 'probeResyncInterval' ifTrue: [^49000035].
	propertyName = 'probeMonitoringEnabled' ifTrue: [^49000036].
	^self error: 'unknown property: "', propertyName, '"'

	"The following code will lookup the property ID in the database based on the propertyName (which now would need a mapping from our names to the names stored in the DB).

	| rows |
	rows := self dbSession execute: ('select idx_ind from frml_desc where str_name = ''', propertyName,'''').
	rows size = 0 ifTrue: [^self error: 'Error loading property id for ""', propertyName, '"" from the database'].
	^rows first at: 1"</body>

<body package="PV-SNMP Collector" selector="routerProbePropertiesForCollector:do:">routerProbePropertiesForCollector: collectorId do: aBlock

	| sql propMap propertyList propIdString bindVars |
	propertyList := #('probeRebootCheckInterval' 'probeResyncInterval' 'probeMonitoringEnabled').
	propMap := Dictionary new.
	propertyList do: [ :propName | propMap at: (self propertyIdFor: propName) put: propName].
	
	sql := 
		'Select /*+ USE_NL(r e) NO_MERGE(r) */ r.Idx_Ind, p.Idx_Metric, p.Str_Value
  			From Prop_Desc p,
       			( Select e.Idx_Ind
           				From ELMT_DESC e
          				Where e.Int_Collector = :1
          			Union All
         			Select /*+ USE_NL(e s) */ s.Idx_Ind
           				From SE_DESC s, ELMT_DESC e
					Where 
						e.Idx_Ind = s.Idx_Host And 
						e.Int_Collector = :1 ) r
			Where 
				p.Idx_Resource = r.Idx_Ind And 
				p.Idx_Metric In ( &lt;1s&gt; )'.

	propIdString := String streamContents: [ :s | (2 to: (propMap size + 1)) do: [ :i | s nextPutAll: ':'; print: i] separatedBy: [s nextPutAll: ', ']].
	bindVars := (Array with: collectorId), propMap keys asArray.
	self dbSession 
		readRowsWith: (sql expandMacrosWith: propIdString)
		bindVars: bindVars
		into: [ :row | aBlock value: row first value: (propMap at: row second) value: row third ].</body>
</methods>


<methods>
<class-id>PROVISO.ProbeMonitor</class-id> <category>db access</category>

<body package="PV-SNMP Collector" selector="dbLoadRoutersForCollector:">dbLoadRoutersForCollector: aNumber
	"Load the routers that have monitored probes from the database"

	| routersFromDB |
	routersFromDB := Dictionary new.
	((self dbInterface routerIdsForCollector: aNumber) collect: [ :ea | ea asNumber])
		do: 
			[ :eaId | 
			routersFromDB 
				at: eaId 
				put: (self createRouterWithId: eaId)].
	self dbInterface 
		routerProbePropertiesForCollector: aNumber
		do: 
			[ :routerId :propName :propValue | 
			(routersFromDB at: routerId ifAbsent: [nil]) ifNotNil: [ :theRouter |
				propName = 'probeRebootCheckInterval' ifTrue: [theRouter rebootCheckInterval: propValue asNumber].
				propName = 'probeResyncInterval' ifTrue: [theRouter resyncInterval: propValue asNumber].
				propName = 'probeMonitoringEnabled' ifTrue: [theRouter monitoringEnabled: (propValue = '1')]]].
	routersFromDB do: [ :ea | ea dbLoadMonitoredProbes].
	self routers: routersFromDB.</body>
</methods>



</st-source>
